@@ -115,22 +115,24 @@ class CuemiacModel (gtk.TreeStore):
         """
         match_iter = self.__match_hashes[hash]
         match_obj = self[match_iter][self.MATCHES]
+        LOGGER.debug ("Adding %i actions to match %r", len(actions), match_obj)
         match_obj.add_all_actions(actions)
     
     def __append_match(self, match_obj, query_string):
-        if len(match_obj.get_actions()) == 0:
-            LOGGER.error("Match %r has no actions" % match_obj)
-            return
-        
         for action in match_obj.get_actions():
             if not action.is_valid():
-                LOGGER.error("Action %r is not valid, removing it" % action)
+                LOGGER.error("Action %r is not valid, removing it", action)
                 match_obj.remove_action(action)
 
+        if len(match_obj.get_actions()) == 0:
+            LOGGER.error("Match %r has no actions", match_obj)
+            return
+        
         if not self.__match_hashes.has_key(match_obj.get_hash()): 
             iter = self.__append ( query_string, match_obj )
             self.__add_to_hash_iter_map(match_obj.get_hash(), iter)
         else:
+            LOGGER.debug("Match %r has the same hash (%s) as a match that has already been added", match_obj, match_obj.get_hash())
             self.__add_actions_to_match(match_obj.get_actions(), match_obj.get_hash())
     
     def append (self, match_obj, query_string):
@@ -193,6 +195,8 @@ class CuemiacModel (gtk.TreeStore):
     def __append_match_to_iter (self, iter, qstring, match_obj):
         action = match_obj.get_actions()[0]
         label = action.get_verb() % action.get_escaped_name(qstring)
+        if match_obj.get_snippet() != None:
+            label += "\n<span size='small' style='italic'>%s</span>" % match_obj.get_snippet()
         iter = self.append_method (self, iter, [qstring, match_obj, label])
         return iter
     
